
============
Contributors code of conduct (on GitHub)
============


1. Purpose


A primary goal of this project is to be **inclusive** to the largest number of contributors, and most importantly **with the most varied and diverse backgrounds possible**. As such, we are committed to providing a friendly, safe and welcoming environment for all, regardless of gender, sexual orientation, ability, ethnicity, socioeconomic status, and religion, or lack of religion thereof.

This code of conduct outlines our expectations for all those who participate to the project, as well as the  consequences for unacceptable behavior.

We invite all those who participate in, to help us create safe and positive experiences for everyone.


2. Open [Source/Culture/Tech] Citizenship


A supplemental goal of this Code of Conduct is to encourage participants to recognize and strengthen the relationships between our actions and their effects on other participants.

Communities mirror the societies in which they exist, and positive action is essential to counteract the many forms of inequality and abuses of power that exist in society.


3. Expected Behavior


The following behaviors are expected and requested of all contributors:

  * **Attempt collaboration before conflict**.
  * Participate in an **authentic** and active way. In doing so, you contribute to the health and longevity of this project.
  * Exercise consideration and respect in your speech and actions.
  * Refrain from demeaning, discriminatory, or harassing behavior and speech.
  * Be mindful of your surroundings and of your fellow participants. 

  
4. Unacceptable Behavior


The following behaviors are considered harassment and are unacceptable:

  * Violence, threats of violence or violent language directed against another person.
  * Sexist, racist, homophobic, transphobic, ableist or otherwise discriminatory jokes and language.
  * Posting or displaying sexually explicit or violent material.
  * Posting or threatening to post other people's personally identifying information ("doxing").
  * Personal insults, particularly those related to gender, sexual orientation, race, religion, or disability.
  * Inappropriate photography or recording.
  * Unwelcome sexual attention. This includes, sexualized comments or jokes.
  * Deliberate intimidation, stalking or following (online or in person).
  * Advocating for, or encouraging, any of the above behavior.


5. Consequences of Unacceptable Behavior


Unacceptable behavior from any contributor will not be tolerated.

Anyone asked to stop unacceptable behavior is expected to comply immediately.

If a contributor engages in unacceptable behavior, appropriate action will be taken, up to and including a temporary ban or permanent expulsion without warning.


6. Scope


We expect all contributors to abide by this Code of Conduct in all venues, online and in-person.


7. Contact info


thierry.moudiki  AT  gmail.com


8. License and attribution

Portions of text derived from the **Citizen Code of Conduct**(http://citizencodeofconduct.org/).



